@@ -45,6 +45,7 @@
 #include <OpenImageIO/imagebufalgo.h>
 #include <OpenImageIO/imageio.h>
 #include <OpenImageIO/strutil.h>
+#include <OpenImageIO/sysutil.h>
 
 #ifdef USE_BOOST_REGEX
 #    include <boost/regex.hpp>
@@ -467,8 +468,8 @@ print_info_subimage(int current_subimage, int max_subimages, ImageSpec& spec,
 
     if (!metamatch.empty()
         && !regex_search(
-               "resolution, width, height, depth, channels, sha-1, stats",
-               field_re)) {
+            "resolution, width, height, depth, channels, sha-1, stats",
+            field_re)) {
         // nothing to do here
         return;
     }
@@ -652,6 +653,10 @@ parse_files(int argc, const char* argv[])
 int
 main(int argc, const char* argv[])
 {
+    // Helpful for debugging to make sure that any crashes dump a stack
+    // trace.
+    Sysutil::setup_crash_stacktrace("stdout");
+
     Filesystem::convert_native_arguments(argc, (const char**)argv);
     ArgParse ap;
     // clang-format off
