@@ -778,8 +778,13 @@ ImageBufImpl::init_spec(string_view filename, int subimage, int miplevel)
     m_nmiplevels   = 0;
     static ustring s_subimages("subimages"), s_miplevels("miplevels");
     static ustring s_fileformat("fileformat");
-    if (m_configspec)  // Pass configuration options to cache
-        m_imagecache->add_file(m_name, nullptr, m_configspec.get());
+    if (m_configspec) {  // Pass configuration options to cache
+        // Invalidate the file in the cache, and add with replacement
+        // because it might have a different config than last time.
+        m_imagecache->invalidate(m_name);
+        m_imagecache->add_file(m_name, nullptr, m_configspec.get(),
+                               /*replace=*/true);
+    }
     m_imagecache->get_image_info(m_name, subimage, miplevel, s_subimages,
                                  TypeInt, &m_nsubimages);
     m_imagecache->get_image_info(m_name, subimage, miplevel, s_miplevels,
@@ -948,13 +953,18 @@ ImageBufImpl::read(int subimage, int miplevel, int chbegin, int chend,
         // loss of range or precision resulting from going through the
         // cache. Or the caller requested a forced read, for that case we
         // also do a direct read now.
-        int unassoc = 0;
-        if (m_imagecache->getattribute("unassociatedalpha", unassoc)) {
-            // Since IB needs to act as if it's backed by an ImageCache,
-            // even though in this case we're bypassing the IC, we need to
-            // honor the IC's "unassociatedalpha" flag.
-            add_configspec();
-            m_configspec->attribute("oiio:UnassociatedAlpha", unassoc);
+        if (!m_configspec
+            || !m_configspec->find_attribute("oiio:UnassociatedAlpha")) {
+            int unassoc = 0;
+            if (m_imagecache->getattribute("unassociatedalpha", unassoc)) {
+                // Since IB needs to act as if it's backed by an ImageCache,
+                // even though in this case we're bypassing the IC, we need
+                // to honor the IC's "unassociatedalpha" flag. But only if
+                // this IB wasn't already given a config spec that dictated
+                // a specific unassociated alpha behavior.
+                add_configspec();
+                m_configspec->attribute("oiio:UnassociatedAlpha", unassoc);
+            }
         }
         auto in = ImageInput::open(m_name.string(), m_configspec.get());
         bool ok = true;
