@@ -368,101 +368,6 @@ test_read_channel_subset()
 
 
 
-void
-test_write_png_to_memory()
-{
-    std::cout << "\nTesting writing a png file to a memory buffer\n";
-
-    // Make a 2x2 red image
-    ImageSpec spec(2, 2, 3, TypeUInt8);
-    ImageBuf buf(spec);
-    float red[3] = { 1, 0, 0 };
-    ImageBufAlgo::fill(buf, red);
-
-    // Use an IOVecOutput proxy to make the bytes go to file_buffer instead
-    // of to disk.
-    std::vector<unsigned char> file_buffer;
-    Filesystem::IOVecOutput memout(file_buffer);
-    void* ptr = &memout;
-    buf.specmod().attribute("oiio:ioproxy", TypeDesc::PTR, &ptr);
-
-    // Write the image. The proxy should do its magic.
-    buf.write("test.png");
-
-    // Check the results against the output of `hexdump test.png` when we
-    // saved the same image to disk. It should be byte-by-byte identical.
-    static const unsigned char reference[] = {
-        0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
-        0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x02,
-        0x08, 0x02, 0x00, 0x00, 0x00, 0xfd, 0xd4, 0x9a, 0x73, 0x00, 0x00, 0x00,
-        0x09, 0x6f, 0x46, 0x46, 0x73, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-        0x00, 0x00, 0xda, 0x2a, 0xb6, 0xce, 0x00, 0x00, 0x00, 0x10, 0x49, 0x44,
-        0x41, 0x54, 0x08, 0x99, 0x63, 0xfc, 0xcf, 0x00, 0x02, 0x4c, 0x60, 0x92,
-        0x01, 0x00, 0x0d, 0x1d, 0x01, 0x03, 0x6e, 0x28, 0x7c, 0x6d, 0x00, 0x00,
-        0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
-    };
-    OIIO_CHECK_EQUAL(file_buffer.size(), 94ul);
-    OIIO_CHECK_ASSERT(
-        !memcmp(file_buffer.data(), reference, file_buffer.size()));
-    OIIO_CHECK_ASSERT(
-        !memcmp(file_buffer.data(), reference, file_buffer.size()));
-    // for (size_t i = 0; i < file_buffer_size; ++i)
-    //     Strutil::printf ("%c%02x", i%16 ? ' ' : '\n', file_buffer[i]);
-    // Strutil::printf ("\n");
-}
-
-
-
-void
-test_write_exr_to_memory()
-{
-    std::cout << "\nTesting writing an exr to a memory buffer\n";
-
-    // Make a 2x2 red image
-    ImageSpec spec(2, 2, 3, TypeHalf);
-    ImageBuf buf(spec);
-    float red[3] = { 1, 0, 0 };
-    ImageBufAlgo::fill(buf, red);
-
-    // Use an IOVecOutput proxy to make the bytes go to file_buffer instead
-    // of to disk.
-    std::vector<unsigned char> file_buffer;
-    Filesystem::IOVecOutput memout(file_buffer);
-    void* ptr = &memout;
-    buf.specmod().attribute("oiio:ioproxy", TypeDesc::PTR, &ptr);
-    // N.B. comment out the above line to write to disk
-
-    // Write the image. The proxy should do its magic.
-    buf.write("test.exr");
-
-    // Check the results against the known size of the disk output.
-    OIIO_CHECK_EQUAL(file_buffer.size(), 383ul);
-
-    // Now read it back again:
-    // * Set up an IOMemReader that reads from the buffer we have
-    Filesystem::IOMemReader memreader(file_buffer);
-    // * Make an config that specifies the memreader as IOProxy.
-    ImageSpec configspec;
-    ptr = &memreader;
-    configspec.attribute("oiio:ioproxy", TypeDesc::PTR, &ptr);
-    // * Make an ImageBuf that uses that config.
-    ImageBuf readbuf("test.exr", 0, 0, nullptr, &configspec);
-    // * The image we read should be the same as the one we started with.
-    OIIO_CHECK_EQUAL(readbuf.spec().height * readbuf.spec().width, 4);
-    for (int y = 0; y < readbuf.spec().height; ++y) {
-        for (int x = 0; x < readbuf.spec().width; ++x) {
-            float rpixel[3], bpixel[3];
-            readbuf.getpixel(x, y, rpixel);
-            buf.getpixel(x, y, bpixel);
-            OIIO_CHECK_EQUAL(rpixel[0], bpixel[0]);
-            OIIO_CHECK_EQUAL(rpixel[1], bpixel[1]);
-            OIIO_CHECK_EQUAL(rpixel[2], bpixel[2]);
-        }
-    }
-}
-
-
-
 void
 test_roi()
 {
@@ -500,93 +405,6 @@ test_roi()
 
 
 
-// This tests a particular troublesome case where we got the logic wrong.
-// Read 1-channel float exr into 4-channel uint8 buffer with 4-byte xstride.
-// The correct behavior is to translate the one channel from float to uint8
-// and put it in channel 0, leaving channels 1-3 untouched. The bug was that
-// because the buffer stride and native stride were both 4 bytes, it was
-// incorrectly doing a straight data copy.
-void
-test_read_tricky_sizes()
-{
-    // Make 4x4 1-channel float source image, value 0.5, write it.
-    char srcfilename[] = "tmp_f1.exr";
-    ImageSpec fsize1(4, 4, 1, TypeFloat);
-    ImageBuf src(fsize1);
-    ImageBufAlgo::fill(src, 0.5f);
-    src.write(srcfilename);
-
-    // Make a 4x4 4-channel uint8 buffer, initialize with 0
-    unsigned char buf[4][4][4];
-    memset(buf, 0, 4 * 4 * 4);
-
-    // Read in, make sure it's right, several different ways
-    {
-        auto imgin = ImageInput::open(srcfilename);
-        imgin->read_image(TypeUInt8, buf, 4 /* xstride */);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-    {
-        memset(buf, 0, 4 * 4 * 4);
-        auto imgin = ImageInput::open(srcfilename);
-        imgin->read_scanlines(0, 0, 0, 4, 0, 0, 4, TypeUInt8, buf,
-                              /*xstride=*/4);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-    {
-        memset(buf, 0, 4 * 4 * 4);
-        auto imgin = ImageInput::open(srcfilename);
-        for (int y = 0; y < 4; ++y)
-            imgin->read_scanline(y, 0, TypeUInt8, buf, /*xstride=*/4);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-    // And repeat for tiled
-    src.set_write_tiles(2, 2);
-    src.write(srcfilename);
-    {
-        memset(buf, 0, 4 * 4 * 4);
-        auto imgin = ImageInput::open(srcfilename);
-        imgin->read_image(TypeUInt8, buf, 4 /* xstride */);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-    {
-        memset(buf, 0, 4 * 4 * 4);
-        auto imgin = ImageInput::open(srcfilename);
-        imgin->read_tiles(0, 0, 0, 4, 0, 4, 0, 1, 0, 4, TypeUInt8, buf,
-                          /*xstride=*/4);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-    {
-        memset(buf, 0, 4 * 4 * 4);
-        auto imgin = ImageInput::open(srcfilename);
-        imgin->read_tile(0, 0, 0, TypeUInt8, buf, /*xstride=*/4);
-        OIIO_CHECK_EQUAL(int(buf[0][0][0]), 128);
-        OIIO_CHECK_EQUAL(int(buf[0][0][1]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][2]), 0);
-        OIIO_CHECK_EQUAL(int(buf[0][0][3]), 0);
-    }
-
-    // Clean up
-    Filesystem::remove(srcfilename);
-}
-
-
-
 int
 main(int argc, char** argv)
 {
@@ -614,11 +432,6 @@ main(int argc, char** argv)
     test_set_get_pixels();
     time_get_pixels();
 
-    test_write_png_to_memory();
-    test_write_exr_to_memory();
-
-    test_read_tricky_sizes();
-
     Filesystem::remove("A_imagebuf_test.tif");
     return unit_test_failures;
 }
