@@ -96,10 +96,6 @@ declare_imageio_format(const std::string& format_name,
     std::vector<std::string> all_extensions;
     // Look for input creator and list of supported extensions
     if (input_creator) {
-        if (input_formats.find(format_name) != input_formats.end()) {
-            input_formats[format_name] = input_creator;
-        }
-        std::string extsym = format_name + "_input_extensions";
         for (const char** e = input_extensions; e && *e; ++e) {
             std::string ext(*e);
             Strutil::to_lower(ext);
@@ -108,13 +104,12 @@ declare_imageio_format(const std::string& format_name,
                 add_if_missing(all_extensions, ext);
             }
         }
+        if (input_formats.find(format_name) == input_formats.end())
+            input_formats[format_name] = input_creator;
     }
 
     // Look for output creator and list of supported extensions
     if (output_creator) {
-        if (output_formats.find(format_name) != output_formats.end()) {
-            output_formats[format_name] = output_creator;
-        }
         for (const char** e = output_extensions; e && *e; ++e) {
             std::string ext(*e);
             Strutil::to_lower(ext);
@@ -123,6 +118,8 @@ declare_imageio_format(const std::string& format_name,
                 add_if_missing(all_extensions, ext);
             }
         }
+        if (output_formats.find(format_name) == output_formats.end())
+            output_formats[format_name] = output_creator;
     }
 
     // Add the name to the master list of format_names, and extensions to
@@ -378,7 +375,8 @@ append_if_env_exists(std::string& searchpath, const char* env,
 void
 pvt::catalog_all_plugins(std::string searchpath)
 {
-    catalog_builtin_plugins();
+    static std::once_flag builtin_flag;
+    std::call_once(builtin_flag, catalog_builtin_plugins);
 
     append_if_env_exists(searchpath, "OIIO_LIBRARY_PATH", true);
 #ifdef __APPLE__
