@@ -40,7 +40,6 @@
 
 #include <boost/container/flat_map.hpp>
 #include <boost/thread/tss.hpp>
-#include <boost/version.hpp>
 
 #include <OpenEXR/half.h>
 
@@ -942,6 +941,8 @@ public:
     get_image_handle(ustring filename,
                      ImageCachePerThreadInfo* thread_info = NULL)
     {
+        if (!thread_info)
+            thread_info = get_perthread_info();
         ImageCacheFile* file = find_file(filename, thread_info);
         return verify_file(file, thread_info);
     }
