@@ -56,13 +56,11 @@
 #    include <boost/regex.hpp>
 using boost::match_results;
 using boost::regex;
-using boost::regex_replace;
 using boost::regex_search;
 #else
 #    include <regex>
 using std::match_results;
 using std::regex;
-using std::regex_replace;
 using std::regex_search;
 #endif
 
@@ -748,15 +746,12 @@ Filesystem::enumerate_file_sequence(const std::string& pattern,
                                     std::vector<std::string>& filenames)
 {
     ASSERT(views.size() == 0 || views.size() == numbers.size());
-    static regex view_re("%V"), short_view_re("%v");
-
     filenames.clear();
     for (size_t i = 0, e = numbers.size(); i < e; ++i) {
         std::string f = pattern;
         if (views.size() > 0 && !views[i].empty()) {
-            f = regex_replace(f, view_re, std::string(views[i]));
-            f = regex_replace(f, short_view_re,
-                              std::string(views[i].substr(0, 1)));
+            f = Strutil::replace(f, "%V", views[i], true);
+            f = Strutil::replace(f, "%v", views[i].substr(0, 1), true);
         }
         f = Strutil::sprintf(f.c_str(), numbers[i]);
         filenames.push_back(f);
@@ -794,10 +789,9 @@ Filesystem::scan_for_matching_filenames(const std::string& pattern,
                 std::vector<std::string> view_filenames;
 
                 std::string view_pattern = pattern;
-                view_pattern             = regex_replace(view_pattern, view_re,
-                                             std::string(view));
-                view_pattern = regex_replace(view_pattern, short_view_re,
-                                             std::string(short_view));
+                view_pattern = Strutil::replace(view_pattern, "%V", view, true);
+                view_pattern = Strutil::replace(view_pattern, "%v", short_view,
+                                                true);
 
                 if (!scan_for_matching_filenames(view_pattern, view_numbers,
                                                  view_filenames))
@@ -823,13 +817,10 @@ Filesystem::scan_for_matching_filenames(const std::string& pattern,
             std::vector<std::pair<string_view, std::string>> matches;
             for (const auto& view : views) {
                 const string_view short_view = view.substr(0, 1);
-
-                std::string view_pattern = pattern;
-                view_pattern             = regex_replace(view_pattern, view_re,
-                                             std::string(view));
-                view_pattern = regex_replace(view_pattern, short_view_re,
-                                             std::string(short_view));
-
+                std::string view_pattern     = pattern;
+                view_pattern = Strutil::replace(view_pattern, "%V", view, true);
+                view_pattern = Strutil::replace(view_pattern, "%v", short_view,
+                                                true);
                 if (exists(view_pattern))
                     matches.push_back(std::make_pair(view, view_pattern));
             }
@@ -931,11 +922,12 @@ Filesystem::IOFile::IOFile(string_view filename, Mode mode)
 {
     // Call Filesystem::fopen since it handles UTF-8 file paths on Windows,
     // which std fopen does not.
-    m_file = Filesystem::fopen(m_filename.c_str(), mode == Write ? "wb" : "rb");
+    m_file = Filesystem::fopen(m_filename.c_str(),
+                               m_mode == Write ? "wb" : "rb");
     if (!m_file)
-        mode = Closed;
+        m_mode = Closed;
     m_auto_close = true;
-    if (mode == Read)
+    if (m_mode == Read)
         m_size = Filesystem::file_size(filename);
 }
 
@@ -943,7 +935,7 @@ Filesystem::IOFile::IOFile(FILE* file, Mode mode)
     : IOProxy("", mode)
     , m_file(file)
 {
-    if (mode == Read) {
+    if (m_mode == Read) {
         m_pos = ftell(m_file);           // save old position
         fseek(m_file, 0, SEEK_END);      // seek to end
         m_size = size_t(ftell(m_file));  // size is end position
@@ -996,17 +988,13 @@ Filesystem::IOFile::pread(void* buf, size_t size, int64_t offset)
     if (!m_file || !size || offset < 0 || m_mode != Read)
         return 0;
 #ifdef _WIN32
-    // See MSDN ReadFile docs:
-    // https://msdn.microsoft.com/en-us/library/windows/desktop/aa365467(v=vs.85).aspx
-    HANDLE h = HANDLE(_get_osfhandle(_fileno(m_file)));
-    OVERLAPPED overlapped;
-    memset(&overlapped, 0, sizeof(overlapped));
-    overlapped.Offset     = DWORD(offset);
-    overlapped.OffsetHigh = DWORD(offset >> 32);
-    DWORD bytesread       = 0;
-    return ReadFile(h, buf, DWORD(size), &bytesread, &overlapped) ? bytesread
-                                                                  : 0;
-#else /* Non-Windows: assume POSIX pwrite is available */
+    std::lock_guard<std::mutex> lock(m_mutex);
+    auto origpos = tell();
+    seek(offset);
+    size_t r = read(buf, size);
+    seek(origpos);
+    return r;
+#else /* Non-Windows: assume POSIX pread is available */
     int fd = fileno(m_file);
     return ::pread(fd, buf, size, offset);
 #endif
@@ -1030,17 +1018,12 @@ Filesystem::IOFile::pwrite(const void* buf, size_t size, int64_t offset)
     if (!m_file || !size || offset < 0 || m_mode != Write)
         return 0;
 #ifdef _WIN32
-    // See MSDN WriteFile docs:
-    // https://msdn.microsoft.com/en-us/library/windows/desktop/aa365747(v=vs.85).aspx
-    HANDLE h = HANDLE(_get_osfhandle(_fileno(m_file)));
-    OVERLAPPED overlapped;
-    memset(&overlapped, 0, sizeof(overlapped));
-    overlapped.Offset     = DWORD(offset);
-    overlapped.OffsetHigh = DWORD(offset >> 32);
-    DWORD byteswritten    = 0;
-    size_t r = WriteFile(h, buf, DWORD(size), &byteswritten, &overlapped)
-                   ? byteswritten
-                   : 0;
+    std::lock_guard<std::mutex> lock(m_mutex);
+    auto origpos = tell();
+    seek(offset);
+    size_t r = write(buf, size);
+    seek(origpos);
+    return r;
 #else /* Non-Windows: assume POSIX pwrite is available */
     int fd   = fileno(m_file);
     size_t r = ::pwrite(fd, buf, size, offset);
