@@ -970,10 +970,31 @@ Strutil::parse_nested(string_view& str, bool eat)
 
 
 
+std::string
+Strutil::excise_string_after_head(std::string& str, string_view head)
+{
+    std::string result;
+    string_view s(str);
+    size_t pattern_start = s.find(head);
+    if (pattern_start != string_view::npos) {
+        // Reposition s to be after the head
+        s.remove_prefix(pattern_start + head.size());
+        string_view m = Strutil::parse_until(s, " \t\r\n");
+        Strutil::skip_whitespace(s);
+        result = m;
+        str    = str.substr(0, pattern_start) + std::string(s);
+    }
+    return result;
+}
+
+
+
 /*
 Copyright for decode function:
 See http://bjoern.hoehrmann.de/utf-8/decoder/dfa/ for details.
 
+MIT license
+
 Copyright (c) 2008-2009 Bjoern Hoehrmann <bjoern@hoehrmann.de>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -1047,6 +1068,10 @@ Strutil::utf8_to_unicode(string_view str, std::vector<uint32_t>& uvec)
 
 
 /* base64 code is based upon: http://www.adp-gmbh.ch/cpp/common/base64.html
+   https://github.com/ReneNyffenegger/cpp-base64
+
+   Zlib license
+
    Copyright (C) 2004-2008 René Nyffenegger
 
    This source code is provided 'as-is', without any express or implied
